OC.L10N.register(
    "spreed",
    {
    "a conversation" : "uma conversa",
    "(Duration %s)" : "(Duração %s)",
    "You attended a call with {user1}" : "Esteve numa chamada com {user1}",
    "_%n guest_::_%n guests_" : ["%n convidado","%n convidados"],
    "You attended a call with {user1} and {user2}" : "Esteve numa chamada com {user1} e {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Esteve numa chamada com {user1}, {user2} e {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Esteve numa chamada com {user1}, {user2}, {user3} e {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Esteve numa chamada com {user1}, {user2}, {user3}, {user4} e {user5}",
    "_%n other_::_%n others_" : ["%n outro","%n outros"],
    "{actor} invited you to {call}" : "{actor} convidou-o para {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Foi convidado para uma <strong>conversa</strong> ou teve uma <strong>chamada</strong>",
    "Talk" : "Falar",
    "Guest" : "Convidado",
    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Bem-vindo ao Nextcloud Talk!\nNesta conversa será informado sobre novas funcionalidades disponíveis no Nextcloud Talk.",
    "New in Talk 6" : "Novo em Talk 6",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- O Microsoft Edge e o Safari podem, agora, ser utilizados para participar em chamadas áudio e vídeo.",
    "Talk to %s" : "Falar com %s",
    "Join call" : "Juntar-se à chamada",
    "{user} wants to talk with you" : "{user} quer falar consigo",
    "A group call has started in {call}" : "Uma chamada de grupo começou em {call}",
    "Open settings" : "Abrir definições",
    "Andorra" : "Andorra",
    "Afghanistan" : "Afeganistão",
    "Armenia" : "Arménia",
    "Angola" : "Angola",
    "Argentina" : "Argentina",
    "Austria" : "Áustria",
    "Australia" : "Austrália",
    "Azerbaijan" : "Azerbaijão",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bélgica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgária",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Botswana" : "Botswana",
    "Canada" : "Canada",
    "Congo" : "Congo",
    "Chile" : "Chile",
    "Cameroon" : "Camarões",
    "China" : "China",
    "Colombia" : "Colômbia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabo Verde",
    "Denmark" : "Dinamarca",
    "Algeria" : "Algéria",
    "Estonia" : "Estónia",
    "Ethiopia" : "Etiópia",
    "Finland" : "Finlândia",
    "France" : "França",
    "Croatia" : "Croácia",
    "Portugal" : "Portugal",
    "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, o formato da data deve ser AAAA-MM-DD",
    "Leave call" : "Sair da chamada",
    "Limit to groups" : "Limitado a grupos",
    "Everyone" : "Para todos",
    "Save changes" : "Guardar alterações",
    "Saved!" : "Gravado!",
    "None" : "Nenhum",
    "User" : "Utilizador",
    "Disabled" : "Desactivado",
    "Users" : "Utilizadores",
    "Name" : "Nome",
    "Language" : "Idioma",
    "Country" : "País",
    "Status" : "Estado",
    "Created at" : "Criado em",
    "Pending" : "Pendente",
    "Error" : "Erro",
    "Blocked" : "Bloqueado",
    "Expired" : "Expirado",
    "Validate SSL certificate" : "Validar certificado SSL",
    "Saved" : "Gravado",
    "Shared secret" : "Segredo partilhado",
    "TURN server protocols" : "Protocolos do servidor TURN",
    "UDP and TCP" : "UDP e TCP",
    "UDP only" : "Só UDP",
    "TCP only" : "Só TCP",
    "Copy link" : "Copiar ligação",
    "Waiting for others to join the call …" : "À espera que outros se juntem à chamada ..",
    "You can invite others in the participant tab of the sidebar" : "Pode convidar outros no separador participantes na barra lateral  ",
    "Share this link to invite others!" : "Envie este link para convidar outros!",
    "Dismiss" : "Dispensar",
    "Mute audio" : "Silenciar áudio",
    "Disable video" : "desactivar vídeo",
    "Enable video" : "activar vídeo",
    "Screensharing options" : "Opções de partilha de ecrã",
    "Enable screensharing" : "Activar partilha de ecrã",
    "Screensharing requires the page to be loaded through HTTPS." : "A partilha de ecrã requer que a página seja carregada através de HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Partilhar o seu ecrã no Firefox apenas funciona com versão 52 ou mais recente. ",
    "Screensharing extension is required to share your screen." : "Extensão de partilha de ecrã é necessária para partilhar o seu ecrã.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor use um browser diferente como o Firefox ou o Chrome para partilhar o seu ecrã.",
    "An error occurred while starting screensharing." : "Ocorreu um erro enquanto iniciava a partilha de ecrã.",
    "You" : "Você",
    "Show screen" : "Mostrar ecrã",
    "Favorite" : "Favorito",
    "Leave conversation" : "Sair da conversação",
    "Delete conversation" : "Eliminar conversação",
    "Remove from favorites" : "Remover de favoritos",
    "Add to favorites" : "Adicionar aos favoritos",
    "Conversations" : "Conversações",
    "Loading" : "A carregar",
    "Groups" : "Grupos",
    "Circles" : "Círculos",
    "Password protect" : "Proteger com palavra-passe",
    "Back" : "Anterior",
    "Close" : "Fechar",
    "Conversation name" : "Nome da conversação",
    "Reply" : "Resposta",
    "Today" : "Hoje",
    "Yesterday" : "Ontem",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Send message" : "Enviar mensagem",
    "moderator" : "moderador",
    "guest" : "convidado",
    "Demote from moderator" : "Relegar de moderador",
    "Promote to moderator" : "Promover a moderador",
    "Remove participant" : "Remover participante",
    "No results" : "Sem resultados",
    "Add users or groups" : "Add users or groups",
    "Participants" : "Participantes",
    "Chat" : "Conversa",
    "Settings" : "Definições",
    "Edit" : "Editar",
    "Rename conversation" : "Renomear conversação",
    "Share link" : "Partilhar hiperligação",
    "Password protection" : "Protegido por palavra-passe",
    "Enter a password" : "Insira uma palavra-passe",
    "Grid view" : "Vista em grelha",
    "Access to microphone & camera is only possible with HTTPS" : "Só é possível aceder ao microfone & câmera com HTTPS",
    "Access to microphone & camera was denied" : "Acesso recusado ao microfone & câmera",
    "WebRTC is not supported in your browser" : "WebRTC não é suportado pelo seu browser",
    "Please use a different browser like Firefox or Chrome" : "Por favor use um browser diferente como Firefox ou Chrome",
    "Error while accessing microphone & camera" : "Erro a aceder ao microfone & câmera",
    "The password is wrong. Try again." : "A palavra-passe está errada. Por favor, tente de novo.",
    "Password" : "Palavra-passe",
    "Android app" : "Aplicação Android",
    "iOS app" : "Aplicação iOS",
    "Copy" : "Copiar",
    "Copied!" : "Copiado!",
    "Not supported!" : "Não suportado!",
    "Press ⌘-C to copy." : "Pressionar ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pressionar Ctrl-C para copiar.",
    "Please enter the password for this call" : "Por favor introduza a palavra-passe para esta chamada",
    "Password required" : "Necessário palavra-passe",
    "Cancel" : "Cancelar",
    "Submit" : "Submeter",
    "Guests" : "Convidados",
    "Change password" : "Alterar palavra-passe",
    "Set password" : "Definir palavra-passe",
    "Rename" : "Renomear",
    "Link copied!" : "Ligação copiada!",
    "Conversation with {name}" : "Conversa com {name}",
    "Error occurred while setting password" : "Ocorreu um erro a definir a palavra-passe",
    "No messages yet, start the conversation!" : "Ainda não tem mensagens, comece a conversa!",
    "New message …" : "Nova mensagem...",
    "Send" : "Enviar",
    "Share" : "Partilhar",
    "[Unknown user name]" : "[Nome de utilizador desconhecido]",
    "Error occurred while sending message" : "Ocorreu um erro a enviar a mensagem",
    "Error while sharing" : "Erro ao partilhar",
    "No other people in this call" : "Sem mais pessoas nesta chamada",
    "Waiting for {participantName} to join the call …" : "À espera que {participantName} se junte à chamada ..",
    "WebRTC is not supported in your browser :-/" : "WebRTC não é suportado pelo seu browser :-/",
    "Waiting for camera and microphone permissions" : "À espera de permissões de câmera e microfone",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Por favor, permite ao seu browser aceder à sua câmera e microfone para que possa utilizar esta aplicação.",
    "No Camera" : "Sem Câmera",
    "Screensharing is not supported by your browser." : "O seu browser não suporta partilha de ecrã",
    "Favorited" : "Nos Favoritos",
    "Your screen" : "O seu ecrã",
    "{participantName}'s screen" : "Ecrã de {participantName}",
    "Guest's screen" : "Ecrã do convidado",
    "Limit app usage to groups." : "Limitar o uso da aplicação a grupos.",
    "Contacts" : "Contactos"
},
"nplurals=2; plural=(n != 1);");
